===========
pyomniscidb
===========

A python `DB API`_ compliant interface for `OmniSci`_ (formerly MapD). 

.. _DB API: https://www.python.org/dev/peps/pep-0249/
.. _OmniSci: https://www.omnisci.com/
